const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const autoprefixer = require('autoprefixer');
const postcssPxtorem = require('postcss-pxtorem');

exports.getBabelLoaderConfig = () => {
  return {
    loader: require.resolve('babel-loader'),
    options: {
      cacheDirectory: true,
      babelrc: false,
      presets: [
        [
          require.resolve('@babel/preset-env'),
          {
            targets: {
              browsers: ['> 1%', 'IE 10'],
            },
            modules: false,
            useBuiltIns: 'entry',
            corejs: 2,
          },
        ],
        // require.resolve('@babel/preset-typescript'),
        require.resolve('@babel/preset-react'),
      ],
      plugins: [
        [require.resolve('babel-plugin-import'), { libraryName: 'antd', style: true, "libraryDirectory": "es" }, "antd"],
        // [require.resolve('babel-plugin-import'), {
        //   "libraryName": "@ant-design/icons",
        //   // "style": false,
        //   "libraryDirectory": "es/icons",
        //   "camel2DashComponentName": false
        // }, "@ant-design/icons"],
        [
          require.resolve('@babel/plugin-transform-runtime'),
          {
            corejs: false,
            helpers: false,
            regenerator: true,
            useESModules: false,
          },
        ],
        require.resolve('@babel/plugin-transform-object-assign'),
        require.resolve('@babel/plugin-syntax-dynamic-import'),
        [require.resolve('@babel/plugin-proposal-decorators'), { legacy: true }],
        [require.resolve('@babel/plugin-proposal-class-properties'), { loose: true }],
        [require.resolve('@babel/plugin-proposal-private-methods'), { loose: true }],
      ].concat(),
      cacheDirectory: true,
      compact: true,
      highlightCode: true,
    },
  };
};

exports.getStyleLoaders = (isPxtoRem, isInJs, cssOptions, preProcessor) => {
  const pxToRemPlugins = [];
  if(isPxtoRem) {
    pxToRemPlugins.push(postcssPxtorem({
      rootValue: 16,
      propList: ['*'],
      selectorBlackList: [],
      replace: true,
      mediaQuery: false,
      minPixelValue: 0,
      unitPrecision: 5,
    }));
  }
  const loaders = [
    isInJs ? MiniCssExtractPlugin.loader : require.resolve('style-loader'),
    {
      loader: cssOptions.modules
        ? require.resolve('typings-for-css-modules-loader')
        : require.resolve('css-loader'),
      options: cssOptions,
    },
    {
      loader: require.resolve('postcss-loader'),
      options: {
        ident: 'postcss',
        plugins: () => [
          //require('postcss-flexbugs-fixes'),
          autoprefixer({
            flexbox: 'no-2009',
          }),

        ].concat(pxToRemPlugins),
      },
    },
  ];
  if (preProcessor) {
    loaders.push(preProcessor);
  }

  // loaders.push({
  //   loader: require.resolve('px2rem-loader'),
  //   options: {
  //     remUni: 75,
  //     remPrecision: 8
  //   }
  // })

  return loaders;
};
